## Issue Details

Please enter any details about your issue here and any of the details
specified below

#### Operating System (uname -a)

#### s4 version (s4 version)

#### python version (python --version)

#### Steps to reproduce the issue

#### DEBUG log output (run with `s4 --log-level=DEBUG`)
